# TimezoneTimeFinder

TimezoneTimeFinder is a package that lets you know in what timezones it's a specific time

* 24 hour version 

    * getTimezones
        
        </br>

        GetTimezones is a function that lets you input the current time and it will respond with a list of time zones where it currently is that specific time.


        `from TimezoneTimeFinder import TimezoneTimeFinder24h
        print(TimezoneTimeFinder24h.getTimezone("13:29"))`


        RESULT:

        `
        ['Africa/Blantyre', 'Africa/Bujumbura', 'Africa/Cairo', 'Africa/Ceuta', 'Africa/Gaborone', 'Africa/Harare', 'Africa/Johannesburg', 'Africa/Juba', 'Africa/Khartoum', 'Africa/Kigali', 'Africa/Lubumbashi', 'Africa/Lusaka', 'Africa/Maputo', 'Africa/Maseru', 'Africa/Mbabane', 'Africa/Tripoli', 'Africa/Windhoek']`
        
        </br>
        </br>



    * getTimezone

        </br>
        GetTimezone is a function that lets you input the current time and it will respond with a one time zone where it currently is that specific time.
        
        
            
        `
        from TimezoneTimeFinder import TimezoneTimeFinder24h
        print(TimezoneTimeFinder24h.getTimezone("13:29"))`


        RESULT:

        `Atlantic/Cape_Verde`
    
    **Inputs:**

    * Both functions takes an input of the time as a string with a colon deviding hours from minutes.

    
    * Both has a minuteCeck input that is turned on by default but by setting it as False it skips the checks for minutes and only looks for hours, wich means that you don't need to input the **current** minute.  
    </br>
    </br>
    </br>




* 12 hour version

    * getTimezones
        
        </br>

        `from TimezoneTimeFinder import TimezoneTimeFinder12h
        print(TimezoneTimeFinder12h.getTimezones(time="00:20", AmPm="am"))`
        
        
        <br/>RESULT: <br/> `['Antarctica/Casey', 'Asia/Magadan', 'Asia/Sakhalin', 'Asia/Srednekolymsk', 'Pacific/Bougainville', 'Pacific/Efate', 'Pacific/Guadalcanal', 'Pacific/Kosrae', 'Pacific/Norfolk', 'Pacific/Noumea', 'Pacific/Pohnpei']` 
        
        <br/>
        <br/>



    * getTimezone

        </br>`from TimezoneTimeFinder import TimezoneTimeFinder12h
    print(TimezoneTimeFinder12h.getTimezone(time="00:15", AmPm="am"))`
    
    
        </br>RESULT: </br> `Antarctica/Casey`  
            

    
    </br></br>
    Everything is the same as the 24h version exccept that you need to specify AM or PM usigng the AmPm input in the functions